/*
 * Copyright © 2003 Maxim Stepin (maxst@hiend3d.com)
 *
 * Copyright © 2010 Cameron Zemek (grom@zeminvaders.net)
 *
 * Copyright © 2011 Tamme Schichler (tamme.schichler@googlemail.com)
 * 
 * Copyright © 2012 A. Eduardo García (arcnorj@gmail.com)
 * 
 * Copyright © 2013 Fabian Praßer (fabian.prasser@gmail.com)
 *
 * This file is part of hqx_dart.
 *
 * hqx_dart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * hqx_dart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with hqx_dart. If not, see <http://www.gnu.org/licenses/>.
 */
part of hqx_dart;

class Hqx {
	static int _Ymask = 0x00FF0000;
	static int _Umask = 0x0000FF00;
	static int _Vmask = 0x000000FF;

	/**
	 * Compares two ARGB colors according to the provided Y, U, V and A thresholds.
	 * @param c1 an ARGB color
	 * @param c2 a second ARGB color
	 * @param trY the Y (luminance) threshold
	 * @param trU the U (chrominance) threshold
	 * @param trV the V (chrominance) threshold
	 * @param trA the A (transparency) threshold
	 * @return true if colors differ more than the thresholds permit, false otherwise
	 */
	static bool _diff(final int c1, final int c2, final int trY, final int trU, final int trV, final int trA) {
		final int YUV1 = RgbYuv._getYuv(c1);
		final int YUV2 = RgbYuv._getYuv(c2);

		return (
				(((YUV1 & _Ymask) - (YUV2 & _Ymask)).abs() > trY) ||
				(((YUV1 & _Umask) - (YUV2 & _Umask)).abs() > trU) ||
				(((YUV1 & _Vmask) - (YUV2 & _Vmask)).abs() > trV) ||
				((((c1 >> 24) - (c2 >> 24))).abs() > trA)
				);
	}
	
	static List<int> _readPixels(ImageData source){

	  List<int> pixels = new List<int>(source.data.length ~/ 4);
	  
	  for (int i=0; i<source.data.length; i+=4){
	    
	    int val = source.data[i+2];
	    val    |= source.data[i+1] << 8;
	    val    |= source.data[i]   << 16;
	    val    |= source.data[i+3] << 24;
	    pixels[i ~/ 4] = val;
	 }
	 return pixels;
	}
	
  static void _writePixels(ImageData destination, List<int> source){

    int idx = 0;
    for (int i=0; i<source.length; i++){
      
      destination.data[idx++] = (source[i] >> 16) & 0x000000FF;
      destination.data[idx++] = (source[i] >> 8 ) & 0x000000FF;
      destination.data[idx++] = (source[i]      ) & 0x000000FF;
      destination.data[idx++] = (source[i] >> 24) & 0x000000FF;
   }
  }

  static ImageData getPixels(ImageElement image){
    CanvasElement canvas = new CanvasElement();
    canvas.width = image.width;
    canvas.height = image.height;
    CanvasRenderingContext2D context = canvas.getContext("2d");
    context.drawImage(image, 0, 0);
    return context.getImageData(0, 0, canvas.width, canvas.height);
  }
  
  static void hq2x_32_rb_default(ImageData source, ImageData destination){
    
      if (destination.width != 2 * source.width) {
        throw new Error();
      } else if (destination.height != 2 * source.height) {
        throw new Error();
      }
      
      List<int> sPixels = _readPixels(source);
      List<int> dPixels = new List<int>(sPixels.length * 4);
      Hqx_2x._hq2x_32_rb_default(sPixels, dPixels, source.width, source.height);
      _writePixels(destination, dPixels);
  }
  
  static void hq2x_32_rb(ImageData source, ImageData destination,
                    int trY, int trU, int trV, int trA,
                    bool wrapX, bool wrapY) {
    
    if (destination.width != 2 * source.width) {
      throw new Error();
    } else if (destination.height != 2 * source.height) {
      throw new Error();
    }
    
    List<int> sPixels = _readPixels(source);
    List<int> dPixels = new List<int>(sPixels.length * 4);
    Hqx_2x._hq2x_32_rb( sPixels, dPixels, source.width, source.height,
                        trY, trU, trV, trA, wrapX, wrapY);
    _writePixels(destination, dPixels);
  }
  

  static void hq3x_32_rb_default(ImageData source, ImageData destination){
    
      if (destination.width != 3 * source.width) {
        throw new Error();
      } else if (destination.height != 3 * source.height) {
        throw new Error();
      }

      List<int> sPixels = _readPixels(source);
      List<int> dPixels = new List<int>(sPixels.length * 9);
      Hqx_3x._hq3x_32_rb_default(sPixels, dPixels, source.width, source.height);
      _writePixels(destination, dPixels);
  }
  
  static void hq3x_32_rb(ImageData source, ImageData destination,
                    int trY, int trU, int trV, int trA,
                    bool wrapX, bool wrapY) {
    
    if (destination.width != 3 * source.width) {
      throw new Error();
    } else if (destination.height != 3 * source.height) {
      throw new Error();
    }
    
    List<int> sPixels = _readPixels(source);
    List<int> dPixels = new List<int>(sPixels.length * 9);
    Hqx_3x._hq3x_32_rb( sPixels, dPixels, source.width, source.height,
                        trY, trU, trV, trA, wrapX, wrapY);
    _writePixels(destination, dPixels);
  }
  

  static void hq4x_32_rb_default(ImageData source, ImageData destination){
    
      if (destination.width != 4 * source.width) {
        throw new Error();
      } else if (destination.height != 4 * source.height) {
        throw new Error();
      }

      List<int> sPixels = _readPixels(source);
      List<int> dPixels = new List<int>(sPixels.length * 16);
      Hqx_4x._hq4x_32_rb_default(sPixels, dPixels, source.width, source.height);
      _writePixels(destination, dPixels);
  }
  
  static void hq4x_32_rb(ImageData source, ImageData destination,
                    int trY, int trU, int trV, int trA,
                    bool wrapX, bool wrapY) {
    
    if (destination.width != 4 * source.width) {
      throw new Error();
    } else if (destination.height != 4 * source.height) {
      throw new Error();
    }

    List<int> sPixels = _readPixels(source);
    List<int> dPixels = new List<int>(sPixels.length * 16);
    Hqx_4x._hq4x_32_rb( sPixels, dPixels, source.width, source.height,
                        trY, trU, trV, trA, wrapX, wrapY);
    _writePixels(destination, dPixels);
  }
  
  static void init() {
    RgbYuv._hqxInit();
  }
  
  static void deinit() {
    RgbYuv._hqxDeinit();
  }
}
